@@ -1,3 +1,5 @@
+import os
+
 import mlflow
 from mlflow.entities import ViewType
 from mlflow.store.tracking.file_store import FileStore
@@ -14,6 +16,7 @@ class ProjectStore(FileStore):
         # uriから`project://` 部分を削除して使う
         if root_directory.startswith('project://'):
             root_directory = root_directory[10:]
+            root_directory = os.path.abspath(root_directory)
         super().__init__(root_directory, artifact_root_uri)
 
     def create_experiment(self, name, artifact_location=None):
