@@ -6,7 +6,7 @@ s3 = boto3.client('s3')
 
 def s3uri_to_console_url(s3uri: str, is_obj: bool):
     s3uri_obj: ParseResult = urlparse(s3uri)
-    bucket_name = s3uri_obj.netloc  # 'bucket.suntory.sic.project-2501'
+    bucket_name = s3uri_obj.netloc
     prefix = s3uri_obj.path[1:] + ('' if is_obj else '/')
     return f"https://s3.console.aws.amazon.com/s3/buckets/{bucket_name}" \
            f"?prefix={prefix}" \
@@ -22,3 +22,5 @@ def s3uri_to_signed_url(s3uri: str):
         Params={'Bucket': bucket, 'Key': key},
         ExpiresIn=3600,
         HttpMethod='GET')
+
+
